@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_Bezier_curve_traits_2.h $
-// $Id: Arr_Bezier_curve_traits_2.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Arrangement_on_surface_2/include/CGAL/Arr_Bezier_curve_traits_2.h $
+// $Id: include/CGAL/Arr_Bezier_curve_traits_2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Ron Wein     <wein@post.tau.ac.il>
@@ -123,7 +123,7 @@ public:
   /// \name Construction.
   //@{
 
-  /*! Default constructor. */
+  /*! constructs default. */
   Arr_Bezier_curve_traits_2 ()
   {
     p_cache = new Bezier_cache;
@@ -131,14 +131,14 @@ public:
     m_owner = true;
   }
 
-  /*! Copy constructor. */
+  /*! constructs copy. */
   Arr_Bezier_curve_traits_2 (const Self& tr) :
     p_cache (tr.p_cache),
     p_inter_map (tr.p_inter_map),
     m_owner (false)
   {}
 
-  /*! Assignment operator. */
+  /*! assigns. */
   Self& operator= (const Self& tr)
   {
     if (this == &tr)
@@ -150,7 +150,7 @@ public:
     return (*this);
   }
 
-  /*! Destructor. */
+  /*! destructs. */
   ~Arr_Bezier_curve_traits_2 ()
   {
     if (m_owner)
@@ -176,13 +176,12 @@ public:
 
   public:
 
-    /*! Constructor. */
+    /*! constructs. */
     Compare_x_2 (const Bezier_cache *cache) :
       p_cache (cache)
     {}
 
-    /*!
-     * Compare the x-coordinates of two points.
+    /*! compares the x-coordinates of two points.
      * \param p1 The first point.
      * \param p2 The second point.
      * \return LARGER if x(p1) > x(p2);
@@ -196,7 +195,7 @@ public:
     }
   };
 
-  /*! Get a Compare_x_2 functor object. */
+  /*! obtains a `Compare_x_2` functor object. */
   Compare_x_2 compare_x_2_object () const
   {
     return (Compare_x_2 (p_cache));
@@ -212,13 +211,12 @@ public:
 
   public:
 
-    /*! Constructor. */
+    /*! constructs. */
     Compare_xy_2 (const Bezier_cache *cache) :
       p_cache (cache)
     {}
 
-    /*!
-     * Compares two points lexigoraphically: by x, then by y.
+    /*! compares two points lexigoraphically: by x, then by y.
      * \param p1 The first point.
      * \param p2 The second point.
      * \return LARGER if x(p1) > x(p2), or if x(p1) = x(p2) and y(p1) > y(p2);
@@ -232,7 +230,7 @@ public:
     }
   };
 
-  /*! Get a Compare_xy_2 functor object. */
+  /*! obtains a `Compare_xy_2` functor object. */
   Compare_xy_2 compare_xy_2_object () const
   {
     return (Compare_xy_2 (p_cache));
@@ -244,8 +242,7 @@ public:
   class Construct_min_vertex_2
   {
   public:
-    /*!
-     * Get the left endpoint of the x-monotone curve (segment).
+    /*! obtains the left endpoint of the x-monotone curve (segment).
      * \param cv The curve.
      * \return The left endpoint.
      */
@@ -255,7 +252,7 @@ public:
     }
   };
 
-  /*! Get a Construct_min_vertex_2 functor object. */
+  /*! obtains a `Construct_min_vertex_2` functor object. */
   Construct_min_vertex_2 construct_min_vertex_2_object () const
   {
     return Construct_min_vertex_2();
@@ -267,8 +264,7 @@ public:
   class Construct_max_vertex_2
   {
   public:
-    /*!
-     * Get the right endpoint of the x-monotone curve (segment).
+    /*! obtains the right endpoint of the x-monotone curve (segment).
      * \param cv The curve.
      * \return The right endpoint.
      */
@@ -278,7 +274,7 @@ public:
     }
   };
 
-  /*! Get a Construct_max_vertex_2 functor object. */
+  /*! obtains a `Construct_max_vertex_2` functor object. */
   Construct_max_vertex_2 construct_max_vertex_2_object () const
   {
     return Construct_max_vertex_2();
@@ -290,8 +286,7 @@ public:
   class Is_vertical_2
   {
   public:
-    /*!
-     * Check whether the given x-monotone curve is a vertical segment.
+    /*! checks whether the given x-monotone curve is a vertical segment.
      * \param cv The curve.
      * \return (true) if the curve is a vertical segment; (false) otherwise.
      */
@@ -301,7 +296,7 @@ public:
     }
   };
 
-  /*! Get an Is_vertical_2 functor object. */
+  /*! obtains an `Is_vertical_2` functor object. */
   Is_vertical_2 is_vertical_2_object () const
   {
     return Is_vertical_2();
@@ -317,13 +312,12 @@ public:
 
   public:
 
-    /*! Constructor. */
+    /*! constructs. */
     Compare_y_at_x_2 (const Bezier_cache *cache) :
       p_cache (cache)
     {}
 
-    /*!
-     * Return the location of the given point with respect to the input curve.
+    /*! returns the location of the given point with respect to the input curve.
      * \param cv The curve.
      * \param p The point.
      * \pre p is in the x-range of cv.
@@ -339,7 +333,7 @@ public:
     }
   };
 
-  /*! Get a Compare_y_at_x_2 functor object. */
+  /*! obtains a `Compare_y_at_x_2` functor object. */
   Compare_y_at_x_2 compare_y_at_x_2_object () const
   {
     return (Compare_y_at_x_2 (p_cache));
@@ -355,13 +349,12 @@ public:
 
   public:
 
-    /*! Constructor. */
+    /*! constructs. */
     Compare_y_at_x_left_2 (const Bezier_cache *cache) :
       p_cache (cache)
     {}
 
-    /*!
-     * Compares the y value of two x-monotone curves immediately to the left
+    /*! compares the y value of two x-monotone curves immediately to the left
      * of their intersection point.
      * \param cv1 The first curve.
      * \param cv2 The second curve.
@@ -380,7 +373,7 @@ public:
     }
   };
 
-  /*! Get a Compare_y_at_x_left_2 functor object. */
+  /*! obtains a `Compare_y_at_x_left_2` functor object. */
   Compare_y_at_x_left_2 compare_y_at_x_left_2_object () const
   {
     return (Compare_y_at_x_left_2 (p_cache));
@@ -396,13 +389,12 @@ public:
 
   public:
 
-    /*! Constructor. */
+    /*! constructs. */
     Compare_y_at_x_right_2 (const Bezier_cache *cache) :
       p_cache (cache)
     {}
 
-    /*!
-     * Compares the y value of two x-monotone curves immediately to the right
+    /*! compares the y value of two x-monotone curves immediately to the right
      * of their intersection point.
      * \param cv1 The first curve.
      * \param cv2 The second curve.
@@ -421,7 +413,7 @@ public:
     }
   };
 
-  /*! Get a Compare_y_at_x_right_2 functor object. */
+  /*! obtains a `Compare_y_at_x_right_2` functor object. */
   Compare_y_at_x_right_2 compare_y_at_x_right_2_object () const
   {
     return (Compare_y_at_x_right_2 (p_cache));
@@ -437,13 +429,12 @@ public:
 
   public:
 
-    /*! Constructor. */
+    /*! constructs. */
     Equal_2 (const Bezier_cache *cache) :
       p_cache (cache)
     {}
 
-    /*!
-     * Check if the two x-monotone curves are the same (have the same graph).
+    /*! checks if the two x-monotone curves are the same (have the same graph).
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \return (true) if the two curves are the same; (false) otherwise.
@@ -455,8 +446,7 @@ public:
                           const_cast<Bezier_cache&> (*p_cache)));
     }
 
-    /*!
-     * Check if the two points are the same.
+    /*! checks if the two points are the same.
      * \param p1 The first point.
      * \param p2 The second point.
      * \return (true) if the two point are the same; (false) otherwise.
@@ -468,7 +458,7 @@ public:
     }
   };
 
-  /*! Get an Equal_2 functor object. */
+  /*! obtains an `Equal_2` functor object. */
   Equal_2 equal_2_object () const
   {
     return (Equal_2 (p_cache));
@@ -486,10 +476,10 @@ public:
     Bezier_cache* p_cache;
 
   public:
-    /*! Constructor. */
+    /*! constructs. */
     Make_x_monotone_2(Bezier_cache* cache) : p_cache(cache) {}
 
-    /*! Subdivide a given Bezier curve into x-monotone subcurves and insert them
+    /*! subdivides a given Bezier curve into x-monotone subcurves and insert them
      * into a given output iterator.
      * \param cv the curve.
      * \param oi an output iterator for the result. Its value type is a variant
@@ -499,7 +489,7 @@ public:
     template <typename OutputIterator>
     OutputIterator operator() (const Curve_2& B, OutputIterator oi) const
     {
-      typedef boost::variant<Point_2, X_monotone_curve_2>
+      typedef std::variant<Point_2, X_monotone_curve_2>
                                                 Make_x_monotone_result;
       typedef typename Bounding_traits::Vertical_tangency_point
                                                 Vertical_tangency_point;
@@ -600,7 +590,7 @@ public:
     }
   };
 
-  /*! Get a Make_x_monotone_2 functor object. */
+  /*! obtains a `Make_x_monotone_2` functor object. */
   Make_x_monotone_2 make_x_monotone_2_object() const
   { return (Make_x_monotone_2 (p_cache)); }
 
@@ -610,8 +600,7 @@ public:
   class Split_2
   {
   public:
-    /*!
-     * Split a given x-monotone curve at a given point into two sub-curves.
+    /*! splits a given x-monotone curve at a given point into two sub-curves.
      * \param cv The curve to split
      * \param p The split point.
      * \param c1 Output: The left resulting subcurve (p is its right endpoint).
@@ -626,7 +615,7 @@ public:
     }
   };
 
-  /*! Get a Split_2 functor object. */
+  /*! obtains a `Split_2` functor object. */
   Split_2 split_2_object () const
   {
     return Split_2();
@@ -643,14 +632,13 @@ public:
 
   public:
 
-    /*! Constructor. */
+    /*! constructs. */
     Intersect_2 (Bezier_cache *cache, Intersection_map *imap) :
       p_cache (cache),
       p_imap (imap)
     {}
 
-    /*!
-     * Find the intersections of the two given curves and insert them to the
+    /*! finds the intersections of the two given curves and insert them to the
      * given output iterator.
      * \param cv1 The first curve.
      * \param cv2 The second curve.
@@ -666,7 +654,7 @@ public:
     }
   };
 
-  /*! Get an Intersect_2 functor object. */
+  /*! obtains an `Intersect_2` functor object. */
   Intersect_2 intersect_2_object () const
   {
     return (Intersect_2 (p_cache, p_inter_map));
@@ -678,8 +666,7 @@ public:
   class Are_mergeable_2
   {
   public:
-    /*!
-     * Check whether it is possible to merge two given x-monotone curves.
+    /*! checks whether it is possible to merge two given x-monotone curves.
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \return (true) if the two curves are mergeable - if they are supported
@@ -692,7 +679,7 @@ public:
     }
   };
 
-  /*! Get an Are_mergeable_2 functor object. */
+  /*! obtains an `Are_mergeable_2` functor object. */
   Are_mergeable_2 are_mergeable_2_object () const
   {
     return Are_mergeable_2();
@@ -709,7 +696,7 @@ public:
     /*! The traits (in case it has state) */
     const Traits* m_traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits (in case it has state)
      */
     Merge_2(const Traits* traits) : m_traits(traits) {}
@@ -718,8 +705,7 @@ public:
                                            Nt_traits, Bounding_traits>;
 
   public:
-    /*!
-     * Merge two given x-monotone curves into a single curve (segment).
+    /*! merges two given x-monotone curves into a single curve (segment).
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \param c Output: The merged curve.
@@ -736,7 +722,7 @@ public:
     }
   };
 
-  /*! Get a Merge_2 functor object. */
+  /*! obtains a `Merge_2` functor object. */
   Merge_2 merge_2_object () const
   {
     return Merge_2(this);
@@ -752,8 +738,7 @@ public:
   class Compare_endpoints_xy_2
   {
   public:
-    /*!
-     * Compare the endpoints of an $x$-monotone curve lexicographically.
+    /*! compares the endpoints of an $x$-monotone curve lexicographically.
      * (assuming the curve has a designated source and target points).
      * \param cv The curve.
      * \return SMALLER if the curve is directed right;
@@ -768,7 +753,7 @@ public:
     }
   };
 
-  /*! Get a Compare_endpoints_xy_2 functor object. */
+  /*! obtains a `Compare_endpoints_xy_2` functor object. */
   Compare_endpoints_xy_2 compare_endpoints_xy_2_object() const
   {
     return Compare_endpoints_xy_2();
@@ -781,16 +766,14 @@ public:
     /*! The traits (in case it has state) */
     const Traits& m_traits;
 
-    /*! Constructor
+    /*! constructs
      * \param traits the traits (in case it has state)
      */
     Trim_2(const Traits& traits) : m_traits(traits) {}
 
     friend class Arr_Bezier_curve_traits_2<Rat_kernel, Alg_kernel,
                                            Nt_traits, Bounding_traits>;
-    /*!\brief
-     * Returns a trimmed version of an arc
-     *
+    /*! returns a trimmed version of an arc
      * \param xcv The arc
      * \param src the new first endpoint
      * \param tgt the new second endpoint
@@ -824,7 +807,7 @@ public:
     }
   };
 
-  /*! Obtain a Trim_2 functor object. */
+  /*! obtains a `Trim_2` functor object. */
   Trim_2 trim_2_object() const { return Trim_2(*this); }
 
   /*! \class Construct_opposite_2
@@ -833,9 +816,7 @@ public:
   class Construct_opposite_2
   {
   public:
-
-    /*!
-     * Construct an opposite x-monotone curve (with swapped source and target).
+    /*! constructs an opposite x-monotone curve (with swapped source and target).
      * \param cv The curve.
      * \return The opposite curve.
      */
@@ -845,7 +826,7 @@ public:
     }
   };
 
-  /*! Get a Construct_opposite_2 functor object. */
+  /*! obtains a `Construct_opposite_2` functor object. */
   Construct_opposite_2 construct_opposite_2_object() const
   {
     return Construct_opposite_2();
@@ -854,8 +835,9 @@ public:
   //@}
 };
 
-} //namespace CGAL
+} // namespace CGAL
 
 #include <CGAL/enable_warnings.h>
+
 #endif
 
