@@ -5,8 +5,8 @@
  *
  * This file is part of CGAL (www.cgal.org).
  *
- * $URL: https://github.com/CGAL/cgal/blob/v6.0.1/CGAL_Core/include/CGAL/CORE/Config.h $
- * $Id: include/CGAL/CORE/Config.h 50cfbde3b84 $
+ * $URL: https://github.com/CGAL/cgal/blob/v6.1/CGAL_Core/include/CGAL/CORE/Config.h $
+ * $Id: include/CGAL/CORE/Config.h b26b07a1242 $
  * SPDX-License-Identifier: LGPL-3.0-or-later
  ***************************************************************************/
 
@@ -29,12 +29,10 @@
 
 #include <CGAL/export/CORE.h>
 
-#ifdef CGAL_TEST_SUITE
-// disabled for the testsuite to avoid `w`
-#define CGAL_CORE_warning_msg(X ,Y)
-// if (!(X)) CGAL_error_msg(Y)
-#else
+#ifdef CGAL_CORE_DEBUG
 #define CGAL_CORE_warning_msg(X ,Y) CGAL_warning_msg(X ,Y)
+#else
+#define CGAL_CORE_warning_msg(X ,Y)
 #endif
 
 
