@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Circular_kernel_2/include/CGAL/Circular_kernel_2/function_objects_on_circle_2.h $
-// $Id: include/CGAL/Circular_kernel_2/function_objects_on_circle_2.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Circular_kernel_2/include/CGAL/Circular_kernel_2/function_objects_on_circle_2.h $
+// $Id: include/CGAL/Circular_kernel_2/function_objects_on_circle_2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
@@ -31,25 +31,29 @@ namespace CGAL {
 namespace CircularFunctors {
 
   template < class CK >
-  class Construct_circle_2 : public CK::Linear_kernel::Construct_circle_2
+  class Construct_circle_2
+    // : public CK::Linear_kernel::Construct_circle_2
   {
-    typedef typename CK::Linear_kernel::Construct_circle_2 Base_functor;
-
     typedef typename CK::FT                         FT;
-    typedef typename CK::Linear_kernel::Point_2     Point_2;
+    typedef typename CK::Circle_2                   Circle_2;
+    typedef typename CK::Circular_arc_2             Circular_arc_2;
+
+    typedef typename CK::Linear_kernel::Construct_circle_2 Linear_Construct_circle_2;
+
   public:
-    typedef typename Base_functor::result_type result_type;
+    // using Linear_Construct_circle_2::operator();
 
-    using Base_functor::operator();
+    template <class... Args>
+    decltype(auto)
+    operator()(const Args&... args) const
+    { return Linear_Construct_circle_2()(args...); }
 
-    typedef typename CK::Circular_arc_2 Circular_arc_2;
-
-    result_type
+    Circle_2
     operator() ( const typename CK::Polynomial_for_circles_2_2 &eq ) {
       return construct_circle_2<CK>(eq);
     }
 
-    result_type
+    decltype(auto)
     operator() (const Circular_arc_2 & a) const {
       return (a.rep().supporting_circle());
     }
