@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/STL_Extension/include/CGAL/Container_helper.h $
-// $Id: Container_helper.h 4f5f834 2022-06-10T07:37:53+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/STL_Extension/include/CGAL/Container_helper.h $
+// $Id: include/CGAL/Container_helper.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,8 +18,9 @@
 #include <CGAL/assertions.h>
 #include <boost/mpl/logical.hpp>
 
+#include <array>
 #include <cstddef>
-#include<type_traits>
+#include <type_traits>
 
 namespace CGAL {
 namespace internal {
@@ -29,29 +30,27 @@ CGAL_GENERATE_MEMBER_DETECTOR(resize);
 
 // Typical container
 template <class Container>
-void resize(Container& c, std::size_t size,
+void resize(Container& c,
+            const std::size_t size,
             std::enable_if_t<has_resize<Container>::value>* = nullptr)
 {
   c.resize(size);
 }
 
-// Container without a resize() function, but with a size() function (e.g. an array)
-template <class Container>
-void resize(Container& CGAL_assertion_code(array), std::size_t CGAL_assertion_code(size),
-            std::enable_if_t<
-              boost::mpl::and_<
-                boost::mpl::not_<has_resize<Container> >,
-                                 has_size<Container> >::value >* = nullptr)
+template <class T, std::size_t s>
+void resize(const std::array<T, s>& CGAL_assertion_code(array),
+            const std::size_t CGAL_assertion_code(size))
 {
   CGAL_assertion(array.size() == size);
 }
 
 // A class with neither resize() nor size(), can't enforce size (it better be correct!)
 template <class Container>
-void resize(Container&, std::size_t,
+void resize(const Container&,
+            const std::size_t,
             std::enable_if_t<
-              !boost::mpl::or_<has_resize<Container>,
-                               has_size<Container> >::value >* = nullptr)
+              !(has_resize<Container>::value ||
+                has_size<Container>::value)>* = nullptr)
 {
 }
 
@@ -61,7 +60,8 @@ CGAL_GENERATE_MEMBER_DETECTOR(reserve);
 
 // Container with 'reserve'
 template <class Container>
-void reserve(Container& c, std::size_t size,
+void reserve(Container& c,
+             const std::size_t size,
              std::enable_if_t<has_reserve<Container>::value>* = nullptr)
 {
   c.reserve(size);
@@ -69,7 +69,8 @@ void reserve(Container& c, std::size_t size,
 
 // Container with no 'reserve'
 template <class Container>
-void reserve(Container&, std::size_t,
+void reserve(const Container&,
+             const std::size_t,
              std::enable_if_t<!has_reserve<Container>::value>* = nullptr)
 {
 }
