@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Mesh_2/include/CGAL/Delaunay_mesh_vertex_base_2.h $
-// $Id: Delaunay_mesh_vertex_base_2.h e3934f1 2021-05-12T15:20:27+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Triangulation_2/include/CGAL/Delaunay_mesh_vertex_base_2.h $
+// $Id: include/CGAL/Delaunay_mesh_vertex_base_2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -13,7 +13,7 @@
 #ifndef CGAL_DELAUNAY_VERTEX_BASE_2_H
 #define CGAL_DELAUNAY_VERTEX_BASE_2_H
 
-#include <CGAL/license/Mesh_2.h>
+#include <CGAL/license/Triangulation_2.h>
 
 
 #include <CGAL/Triangulation_vertex_base_2.h>
@@ -67,7 +67,7 @@ public:
 
   void set_time_stamp(const std::size_t& ts) { time_stamp_ = ts; }
 
-  std::size_t time_stamp_;
+  std::size_t time_stamp_ = std::size_t(-2);
 #endif // CGAL_MESH_2_DEBUG_REFINEMENT_POINTS
 };
 
