@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Distance_3/include/CGAL/Distance_3/Ray_3_Line_3.h $
-// $Id: include/CGAL/Distance_3/Ray_3_Line_3.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Distance_3/include/CGAL/Distance_3/Ray_3_Line_3.h $
+// $Id: include/CGAL/Distance_3/Ray_3_Line_3.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -77,26 +77,28 @@ squared_distance(const typename K::Line_3& line,
   return squared_distance(ray, line, k);
 }
 
+template <class K>
+typename K::Comparison_result
+compare_squared_distance(const typename K::Ray_3& ray,
+                         const typename K::Line_3& line,
+                         const K& k,
+                         const typename K::FT& d2)
+{
+  return ::CGAL::compare(squared_distance(ray, line, k), d2);
+}
+
+template <class K>
+typename K::Comparison_result
+compare_squared_distance(const typename K::Line_3& line,
+                         const typename K::Ray_3& ray,
+                         const K& k,
+                         const typename K::FT& d2)
+{
+  return compare_squared_distance(ray, line, k, d2);
+}
+
 } // namespace internal
 
-template <class K>
-inline
-typename K::FT
-squared_distance(const Line_3<K>& line,
-                 const Ray_3<K>& ray)
-{
-  return K().compute_squared_distance_3_object()(line, ray);
-}
-
-template <class K>
-inline
-typename K::FT
-squared_distance(const Ray_3<K>& ray,
-                 const Line_3<K>& line)
-{
-  return K().compute_squared_distance_3_object()(ray, line);
-}
-
 } // namespace CGAL
 
 #endif // CGAL_DISTANCE_3_RAY_3_LINE_3_H
