@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Filtered_kernel/include/CGAL/Filtered_kernel/internal/Static_filters/Compare_distance_3.h $
-// $Id: include/CGAL/Filtered_kernel/internal/Static_filters/Compare_distance_3.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Filtered_kernel/include/CGAL/Filtered_kernel/internal/Static_filters/Compare_distance_3.h $
+// $Id: include/CGAL/Filtered_kernel/internal/Static_filters/Compare_distance_3.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -30,17 +30,16 @@ template < typename K_base >
 class Compare_distance_3
   : public K_base::Compare_distance_3
 {
-  typedef typename K_base::Point_3   Point_3;
-  typedef typename K_base::Vector_3  Vector_3;
+  typedef typename K_base::Comparison_result    Comparison_result;
+  typedef typename K_base::Point_3              Point_3;
+  typedef typename K_base::Vector_3             Vector_3;
+
   typedef typename K_base::Compare_distance_3   Base;
 
 public:
-
-  typedef typename Base::result_type  result_type;
-
   using Base::operator();
 
-  result_type operator()(const Point_3 &p, const Point_3& q, const Point_3& r) const
+  Comparison_result operator()(const Point_3& p, const Point_3& q, const Point_3& r) const
   {
     CGAL_BRANCH_PROFILER(std::string("semi-static attempts/calls to   : ") +
                          std::string(CGAL_PRETTY_FUNCTION), tmp);
