@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Stream_support/include/CGAL/IO/io_tags.h $
-// $Id: include/CGAL/IO/io_tags.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Stream_support/include/CGAL/IO/io_tags.h $
+// $Id: include/CGAL/IO/io_tags.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -51,7 +51,7 @@ template<> struct Io_traits<float> { typedef io_Read_write Io_tag; };
 template<> struct Io_traits<double> { typedef io_Read_write Io_tag; };
 template<> struct Io_traits<long double> { typedef io_Read_write Io_tag; };
 
-
+struct IO_manip_tag{};
 
 } //namespace CGAL
 
