@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Kernel_23/include/CGAL/Kernel_23/internal/Projection_traits_base_3.h $
-// $Id: Projection_traits_base_3.h 4547818 2022-11-15T13:39:40+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Kernel_23/include/CGAL/Kernel_23/internal/Projection_traits_base_3.h $
+// $Id: include/CGAL/Kernel_23/internal/Projection_traits_base_3.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -35,7 +35,6 @@ class Projected_orientation_with_normal_3
   typedef typename Traits::Vector_3 Vector_3;
 public:
   typedef typename K::Orientation Orientation;
-  typedef Orientation result_type;
 
   Projected_orientation_with_normal_3(const Vector_3& normal_)
     : normal(normal_)
@@ -70,7 +69,6 @@ class Projected_side_of_oriented_circle_with_normal_3
 
 public:
   typedef typename K::Oriented_side Oriented_side;
-  typedef Oriented_side result_type;
 
   Projected_side_of_oriented_circle_with_normal_3(const Vector_3& normal_)
     : normal(normal_)
@@ -183,12 +181,12 @@ public:
     CGAL_TIME_PROFILER("Construct Projected_intersect_3")
   }
 
-  boost::optional<boost::variant<Point,Segment> >
+  std::optional<std::variant<Point,Segment> >
   operator()(const Segment& s1, const Segment& s2)
   {
     CGAL_PROFILER("Projected_intersect_3::operator()")
     CGAL_TIME_PROFILER("Projected_intersect_3::operator()")
-    typedef boost::variant<Point, Segment> variant_type;
+    typedef std::variant<Point, Segment> variant_type;
     const Vector_3 u1 = cross_product(s1.to_vector(), normal);
     if(u1 == NULL_VECTOR)
       return K().intersect_3_object()(s1.supporting_line(), s2);
@@ -205,9 +203,9 @@ public:
 #ifdef CGAL_T2_PTB_3_DEBUG
       Rcpp::Rcerr << "planes_intersection is empty\n";
 #endif
-      return boost::none;
+      return std::nullopt;
     }
-    if(const Line* line = boost::get<Line>(&*planes_intersection))
+    if(const Line* line = std::get_if<Line>(&*planes_intersection))
     {
       // check if the intersection line intersects both segments by
       // checking if a point on the intersection line is between
@@ -223,7 +221,7 @@ public:
 #ifdef CGAL_T2_PTB_3_DEBUG
         Rcpp::Rcerr << "intersection not inside\n";
 #endif
-        return boost::none;
+        return std::nullopt;
       }
       else
       {
@@ -234,14 +232,14 @@ public:
                                                  cross_product(s1.to_vector(),
                                                                s2.to_vector())));
         if(! inter){
-          return boost::none;
+          return std::nullopt;
         }
-        if(const Point* point = boost::get<Point>(&*inter)){
-          return boost::make_optional(variant_type(*point));
+        if(const Point* point = std::get_if<Point>(&*inter)){
+          return std::make_optional(variant_type(*point));
         }
       }
     }
-    if(boost::get<Plane_3>(&*planes_intersection))
+    if(std::get_if<Plane_3>(&*planes_intersection))
     {
 #ifdef CGAL_T2_PTB_3_DEBUG
       Rcpp::Rcerr << "coplanar supporting lines\n";
@@ -256,50 +254,50 @@ public:
       bool src1_in_s2 = is_inside_segment(s2, s1.source());
       bool tgt1_in_s2 = is_inside_segment(s2, s1.target());
 
-      if (src1_in_s2 && tgt1_in_s2) return boost::make_optional(variant_type(s1));
-      if (src2_in_s1 && tgt2_in_s1) return boost::make_optional(variant_type(s2));
+      if (src1_in_s2 && tgt1_in_s2) return std::make_optional(variant_type(s1));
+      if (src2_in_s1 && tgt2_in_s1) return std::make_optional(variant_type(s2));
 
       if (src1_in_s2)
       {
         if (src2_in_s1)
         {
           if (cross_product(normal, Vector_3(s1.source(), s2.source())) != NULL_VECTOR)
-            return boost::make_optional(variant_type(Segment(s1.source(), s2.source())));
+            return std::make_optional(variant_type(Segment(s1.source(), s2.source())));
           else
-            return boost::make_optional(variant_type((s1.source())));
+            return std::make_optional(variant_type((s1.source())));
         }
         if (tgt2_in_s1)
         {
           if (cross_product(normal, Vector_3(s1.source(), s2.target())) != NULL_VECTOR)
-            return boost::make_optional(variant_type(Segment(s1.source(), s2.target())));
+            return std::make_optional(variant_type(Segment(s1.source(), s2.target())));
           else
-            return boost::make_optional(variant_type(s1.source()));
+            return std::make_optional(variant_type(s1.source()));
         }
         // should never get here with a Kernel with exact constructions
-        return boost::make_optional(variant_type(s1.source()));
+        return std::make_optional(variant_type(s1.source()));
       }
       if (tgt1_in_s2)
       {
         if (src2_in_s1)
         {
           if (cross_product(normal, Vector_3(s1.target(), s2.source())) != NULL_VECTOR)
-            return boost::make_optional(variant_type(Segment(s1.target(), s2.source())));
+            return std::make_optional(variant_type(Segment(s1.target(), s2.source())));
           else
-            return boost::make_optional(variant_type(s1.target()));
+            return std::make_optional(variant_type(s1.target()));
         }
         if (tgt2_in_s1)
         {
           if (cross_product(normal, Vector_3(s1.target(), s2.target())) != NULL_VECTOR)
-            return boost::make_optional(variant_type(Segment(s1.target(), s2.target())));
+            return std::make_optional(variant_type(Segment(s1.target(), s2.target())));
           else
-            return boost::make_optional(variant_type(s1.target()));
+            return std::make_optional(variant_type(s1.target()));
         }
         // should never get here with a Kernel with exact constructions
-        return boost::make_optional(variant_type(s1.target()));
+        return std::make_optional(variant_type(s1.target()));
       }
-      return boost::none;
+      return std::nullopt;
     }
-    return boost::none;
+    return std::nullopt;
   }
 }; // end class Projected_intersect_3
 
@@ -308,6 +306,7 @@ template <class Traits>
 class Less_along_axis
 {
   // private members
+  typedef typename Traits::Boolean Boolean;
   typedef typename Traits::Vector_3 Vector_3;
   typedef typename Traits::Point_2 Point;
   Vector_3 base;
@@ -318,9 +317,7 @@ public:
     CGAL_TIME_PROFILER("Construct Less_along_axis")
   }
 
-  typedef bool result_type;
-
-  bool operator() (const Point &p, const Point &q) const {
+  Boolean operator() (const Point &p, const Point &q) const {
     return base * (p - q) < 0;
   }
 }; // end class Less_along_axis
@@ -329,6 +326,7 @@ template <class Traits>
 class Compare_along_axis
 {
   // private members
+  typedef typename Traits::Comparison_result Comparison_result;
   typedef typename Traits::Vector_3 Vector_3;
   typedef typename Traits::Point_2 Point;
   Vector_3 base;
@@ -339,8 +337,6 @@ public:
     CGAL_TIME_PROFILER("Construct Compare_along_axis")
   }
 
-  typedef Comparison_result result_type;
-
   Comparison_result operator() (const Point &p, const Point &q) const {
     return compare(base * (p - q), 0);
   }
@@ -350,9 +346,13 @@ template <class Traits>
 class Less_xy_along_axis
 {
   // private members
+  typedef typename Traits::Comparison_result Comparison_result;
+  typedef typename Traits::Boolean Boolean;
   typedef typename Traits::Vector_3 Vector_3;
   typedef typename Traits::Point_2 Point;
+
   Vector_3 base1, base2;
+
 public:
   Less_xy_along_axis(const Vector_3& base1, const Vector_3& base2) : base1(base1), base2(base2)
   {
@@ -360,9 +360,7 @@ public:
     CGAL_TIME_PROFILER("Construct Less_xy_along_axis")
   }
 
-  typedef bool result_type;
-
-  bool operator() (const Point &p, const Point &q) const {
+  Boolean operator() (const Point &p, const Point &q) const {
 
     Compare_along_axis<Traits> cx(base1);
     Comparison_result crx = cx(p, q);
@@ -373,6 +371,34 @@ public:
   }
 }; // end class Less_xy_along_axis
 
+template <class Traits>
+class Compare_xy_along_axis
+{
+  // private members
+  typedef typename Traits::Comparison_result Comparison_result;
+  typedef typename Traits::Vector_3 Vector_3;
+  typedef typename Traits::Point_2 Point;
+  Vector_3 base1, base2;
+
+public:
+  Compare_xy_along_axis(const Vector_3& base1, const Vector_3& base2) : base1(base1), base2(base2)
+  {
+    CGAL_PROFILER("Construct Compare_xy_along_axis")
+    CGAL_TIME_PROFILER("Construct Compare_xy_along_axis")
+  }
+
+  Comparison_result operator()(const Point& p, const Point& q) const
+  {
+    Compare_along_axis<Traits> cx(base1);
+    Comparison_result crx = cx(p, q);
+    if (crx != EQUAL) {
+      return crx;
+    }
+    Compare_along_axis<Traits> cy(base2);
+    return cy(p, q);
+  }
+}; // end class Compare_xy_along_axis
+
 } // end namespace TriangulationProjectionTraitsCartesianFunctors
 
 
@@ -419,6 +445,15 @@ public:
   }
 
   typedef Kernel K;
+
+  typedef typename K::Boolean                                Boolean;
+  typedef typename K::Sign                                   Sign;
+  typedef typename K::Comparison_result                      Comparison_result;
+  typedef typename K::Orientation                            Orientation;
+  typedef typename K::Oriented_side                          Oriented_side;
+  typedef typename K::Bounded_side                           Bounded_side;
+  typedef typename K::Angle                                  Angle;
+
   typedef typename K::FT          FT;
   typedef typename K::Point_3     Point_2;
   typedef typename K::Segment_3   Segment_2;
@@ -432,6 +467,8 @@ public:
     Compare_along_axis<Self>                                 Compare_x_2;
   typedef TriangulationProjectionTraitsCartesianFunctors::
     Compare_along_axis<Self>                                 Compare_y_2;
+  typedef TriangulationProjectionTraitsCartesianFunctors::
+    Compare_xy_along_axis<Self>                              Compare_xy_2;
 
   typedef TriangulationProjectionTraitsCartesianFunctors::
     Less_along_axis<Self>                                    Less_x_2;
@@ -498,6 +535,12 @@ public:
     return Compare_y_2(this->base2());
   }
 
+  Compare_xy_2
+  compare_xy_2_object() const
+  {
+    return Compare_xy_2(this->base1(), this->base2());
+  }
+
   Orientation_2
   orientation_2_object() const
   {
