@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Number_types/include/CGAL/Lazy_exact_nt.h $
-// $Id: Lazy_exact_nt.h 3674c93 2022-11-15T15:21:01+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Number_types/include/CGAL/Lazy_exact_nt.h $
+// $Id: include/CGAL/Lazy_exact_nt.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,9 +18,7 @@
 
 #include <CGAL/boost/iterator/transform_iterator.hpp> // for Root_of functor
 #include <boost/operators.hpp>
-#include <boost/type_traits/is_arithmetic.hpp>
 
-#include <boost/mpl/if.hpp>
 #include <boost/mpl/logical.hpp>
 
 #include <CGAL/Interval_nt.h>
@@ -34,6 +32,8 @@
 #include <CGAL/Kernel/mpl.h>
 #include <CGAL/tss.h>
 #include <CGAL/type_traits.h>
+#include <CGAL/Number_types/internal/Exact_type_selector.h>
+
 
 #include<type_traits>
 
@@ -382,9 +382,9 @@ public :
 
   // Also check that ET and AT are constructible from T?
   template<class T>
-  Lazy_exact_nt (T i, std::enable_if_t<boost::mpl::and_<
-      boost::mpl::or_<boost::is_arithmetic<T>, std::is_enum<T> >,
-      boost::mpl::not_<std::is_same<T,ET> > >::value,void*> = 0)
+  Lazy_exact_nt (T i, std::enable_if_t<
+      (std::is_arithmetic_v<T> || std::is_enum_v<T>) &&
+      !std::is_same_v<T,ET>,void*> = 0)
     : Base(new Lazy_exact_Cst<ET,T>(i)) {}
 
   Lazy_exact_nt (const ET & e)
@@ -944,9 +944,9 @@ struct Div_mod_selector {
     void operator()( const NT1& x, const NT2& y,
                      NT& q,
                      NT& r ) const {
-      CGAL_static_assertion((::std::is_same<
+      static_assert(::std::is_same<
         typename Coercion_traits< NT1, NT2 >::Type, NT
-                                              >::value));
+                                              >::value);
 
       typename Coercion_traits< NT1, NT2 >::Cast cast;
       operator()( cast(x), cast(y), q, r );
@@ -1029,8 +1029,8 @@ template < typename ET > class Real_embeddable_traits< Lazy_exact_nt<ET> >
   : public INTERN_RET::Real_embeddable_traits_base< Lazy_exact_nt<ET> , CGAL::Tag_true > {
 
   // Every type ET of Lazy_exact_nt<ET> has to be real embeddable.
-  CGAL_static_assertion((::std::is_same< typename Real_embeddable_traits< ET >
-                                ::Is_real_embeddable, Tag_true >::value));
+  static_assert(::std::is_same< typename Real_embeddable_traits< ET >
+                                ::Is_real_embeddable, Tag_true >::value);
 
   public:
     typedef Lazy_exact_nt<ET> Type;
@@ -1178,12 +1178,11 @@ struct Coercion_traits< Lazy_exact_nt<ET1>, Lazy_exact_nt<ET2> >
         Are_implicit_interoperable;                                     \
     private:                                                            \
         static const  bool interoperable                                \
-        =std::is_same< Are_implicit_interoperable, Tag_false>::value; \
+        =std::is_same< Are_implicit_interoperable, Tag_false>::value;   \
     public:                                                             \
-        typedef typename boost::mpl::if_c <interoperable,Null_tag,NT>   \
-        ::type  Type;                                          \
-        typedef typename boost::mpl::if_c <interoperable, Null_functor, \
-    INTERN_CT::Cast_from_to<NTX,NT> >::type Cast;                       \
+        typedef std::conditional_t <interoperable,Null_tag,NT> Type;    \
+        typedef std::conditional_t <interoperable, Null_functor,        \
+    INTERN_CT::Cast_from_to<NTX,NT> > Cast;                             \
     };                                                                  \
                                                                         \
     template<class ET>                                                  \
@@ -1427,7 +1426,24 @@ class Modular_traits<Lazy_exact_nt<ET> >
 #undef CGAL_int
 #undef CGAL_To_interval
 
-} //namespace CGAL
+namespace internal {
+
+template < typename ET >
+struct Exact_field_selector<Lazy_exact_nt<ET> >
+: Exact_field_selector<ET>
+{
+  // We have a choice here :
+  // - using ET gets rid of the DAG computation as well as redoing the interval
+  // - using Lazy_exact_nt<ET> might use sharper intervals.
+  // typedef ET  Type;
+  // typedef Lazy_exact_nt<ET>  Type;
+};
+template < typename ET >
+struct Exact_ring_selector<Lazy_exact_nt<ET> >
+: Exact_ring_selector<ET>
+{};
+
+} } //namespace CGAL::internal
 
 namespace Eigen {
   template<class> struct NumTraits;
