@@ -4,9 +4,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Nef_2/include/CGAL/Nef_2/debug.h $
-// $Id: debug.h ce7d06d 2020-12-05T08:12:56+00:00 Giles Bathgate
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Nef_2/include/CGAL/Nef_2/debug.h $
+// $Id: include/CGAL/Nef_2/debug.h b26b07a1242 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
@@ -14,6 +14,9 @@
 #ifndef CGAL_NEF_2_DEBUG_H
 #define CGAL_NEF_2_DEBUG_H
 
+#include <CGAL/license/Nef_2.h>
+
+
 #include <iostream>
 
 #ifdef NDEBUG
