@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/measure.h $
-// $Id: include/CGAL/Polygon_mesh_processing/measure.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/measure.h $
+// $Id: include/CGAL/Polygon_mesh_processing/measure.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -912,6 +912,8 @@ centroid(const TriangleMesh& tmesh,
   Scale scale = k.construct_scaled_vector_3_object();
   Sum sum = k.construct_sum_of_vectors_3_object();
 
+  ::CGAL::internal::Evaluate<FT> evaluate;
+
   for(face_descriptor fd : faces(tmesh))
   {
     const Point_3_ref p = get(vpm, target(halfedge(fd, tmesh), tmesh));
@@ -922,6 +924,7 @@ centroid(const TriangleMesh& tmesh,
              vr = vector(ORIGIN, r);
     Vector_3 n = normal(p, q, r);
     volume += (scalar_product(n,vp))/FT(6);
+    evaluate(volume);
     n = scale(n, FT(1)/FT(24));
 
     Vector_3 v2 = sum(vp, vq);
@@ -932,6 +935,7 @@ centroid(const TriangleMesh& tmesh,
     v3 = sum(v3, Vector_3(square(v2.x()), square(v2.y()), square(v2.z())));
 
     centroid = sum(centroid, Vector_3(n.x() * v3.x(), n.y() * v3.y(), n.z() * v3.z()));
+    evaluate(centroid);
   }
 
   centroid = scale(centroid, FT(1)/(FT(2)*volume));
