@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/STL_Extension/include/CGAL/STL_Extension/internal/mesh_parameters_interface.h $
-// $Id: include/CGAL/STL_Extension/internal/mesh_parameters_interface.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/STL_Extension/include/CGAL/STL_Extension/internal/mesh_parameters_interface.h $
+// $Id: include/CGAL/STL_Extension/internal/mesh_parameters_interface.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -369,3 +369,16 @@ features(const MeshDomain& /*domain*/)
   return CGAL_NP_BUILD(Param,Generator()());
 }
 
+// -----------------------------------
+// Surface only (replacing Surface_mesher)
+// -----------------------------------
+inline Named_function_parameters<::CGAL::parameters::internal::Mesh_3_options, ::CGAL::internal_np::mesh_param_t, CGAL_NP_BASE>
+surface_only()
+{
+  typedef Named_function_parameters<::CGAL::parameters::internal::Mesh_3_options, ::CGAL::internal_np::mesh_param_t, CGAL_NP_BASE> Param;
+  ::CGAL::parameters::internal::Mesh_3_options options;
+
+  options.surface_only = true;
+  return CGAL_NP_BUILD(Param, options);
+}
+
