@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Orientation_C2.h $
-// $Id: include/CGAL/Segment_Delaunay_graph_2/Orientation_C2.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Orientation_C2.h $
+// $Id: include/CGAL/Segment_Delaunay_graph_2/Orientation_C2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -163,9 +163,6 @@ private:
   }
 
 public:
-  typedef Orientation                  result_type;
-  typedef Site_2                       argument_type;
-
   Orientation operator()(const Site_2& p, const Site_2& q,
                          const Site_2& r) const
   {
