@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Linear_cell_complex/include/CGAL/draw_linear_cell_complex.h $
-// $Id: include/CGAL/draw_linear_cell_complex.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Linear_cell_complex/include/CGAL/draw_linear_cell_complex.h $
+// $Id: include/CGAL/draw_linear_cell_complex.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -13,7 +13,7 @@
 #ifndef CGAL_DRAW_LCC_H
 #define CGAL_DRAW_LCC_H
 
-#include <CGAL/Qt/Basic_viewer.h>
+#include <CGAL/Basic_viewer.h>
 #include <CGAL/Graphics_scene.h>
 #include <CGAL/Graphics_scene_options.h>
 #include <CGAL/Linear_cell_complex_base.h>
@@ -289,8 +289,6 @@ void add_to_graphics_scene(const CGAL_LCC_TYPE& alcc,
   add_to_graphics_scene(alcc, graphics_scene, gso);
 }
 
-#ifdef CGAL_USE_BASIC_VIEWER
-
 // Specialization of draw function for a LCC, with a drawing graphics scene options.
 template<unsigned int d_, unsigned int ambient_dim, class Traits_,
          class Items_, class Alloc_,
@@ -317,8 +315,6 @@ void draw(const CGAL_LCC_TYPE& alcc, const char *title="LCC Basic Viewer")
   draw_graphics_scene(buffer, title);
 }
 
-#endif // CGAL_USE_BASIC_VIEWER
-
 #undef CGAL_LCC_TYPE
 
 } // End namespace CGAL
