@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Point_set_processing_3/include/CGAL/mst_orient_normals.h $
-// $Id: mst_orient_normals.h 6e6598c 2023-10-10T19:32:59+02:00 Jane Tournois
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Point_set_processing_3/include/CGAL/mst_orient_normals.h $
+// $Id: include/CGAL/mst_orient_normals.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Laurent Saboret and Andreas Fabri
@@ -388,7 +388,7 @@ create_riemannian_graph(
                 // Add edge
                 typename boost::graph_traits<Riemannian_graph>::edge_descriptor e;
                 bool inserted;
-                boost::tie(e, inserted) = add_edge(vertex(it_index, riemannian_graph),
+                std::tie(e, inserted) = add_edge(vertex(it_index, riemannian_graph),
                                                    vertex(neighbor_index, riemannian_graph),
                                                    riemannian_graph);
                 CGAL_assertion(inserted);
@@ -410,7 +410,7 @@ create_riemannian_graph(
         {
           typename boost::graph_traits<Riemannian_graph>::edge_descriptor e;
           bool inserted;
-          boost::tie(e, inserted) = add_edge(vertex(it_index, riemannian_graph),
+          std::tie(e, inserted) = add_edge(vertex(it_index, riemannian_graph),
                                              vertex(source_point_index, riemannian_graph),
                                              riemannian_graph);
           CGAL_assertion(inserted);
@@ -549,9 +549,6 @@ create_mst_graph(
    For this reason it should not be called on sorted containers.
    It is based on \cgalCite{cgal:hddms-srup-92}.
 
-   \warning This function may fail when Boost version 1.54 is used,
-   because of the following bug: https://svn.boost.org/trac/boost/ticket/9012
-
    \pre Normals must be unit vectors
    \pre `k >= 2`
 
