@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Property_map/include/CGAL/property_map.h $
-// $Id: property_map.h 9242a81 2023-02-07T11:31:55+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Property_map/include/CGAL/property_map.h $
+// $Id: include/CGAL/property_map.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Andreas Fabri and Laurent Saboret
@@ -73,9 +73,7 @@ class OR_property_map {
   typedef typename PM1::reference reference;
   typedef boost::read_write_property_map_tag category;
 
-  OR_property_map() {} // required by boost::connected_components
-
-  OR_property_map(PM1 pm1, PM2 pm2)
+  OR_property_map(PM1 pm1 = PM1(), PM2 pm2 = PM2())
     : pm1(pm1),pm2(pm2)
   {}
 
@@ -104,7 +102,7 @@ make_OR_property_map(const PM1& pm1, const PM2& pm2)
 
 /// Property map that accesses a value from an iterator
 ///
-/// \cgalModels `ReadablePropertyMap`
+/// \cgalModels{ReadablePropertyMap}
 ///
 /// \tparam InputIterator an input iterator
 /// \endcond
@@ -289,7 +287,7 @@ make_compose_property_map(const KeyMap& km, const ValueMap& vm)
 /// Property map that converts a `T*` pointer (or in general an iterator
 /// over `T` elements) to the `T` object.
 ///
-/// \cgalModels `LvaluePropertyMap`
+/// \cgalModels{LvaluePropertyMap}
 template <typename T, typename Iter = T*>
 struct Dereference_property_map
   : public boost::put_get_helper<typename std::iterator_traits<Iter>::reference, Dereference_property_map<T, Iter> >
@@ -321,7 +319,7 @@ make_dereference_property_map(Iter)
 /// A `LvaluePropertyMap` property map mapping a key to itself (by reference).
 /// It is mutable if `T` is not `const` and non-mutable otherwise.
 ///
-/// \cgalModels `LvaluePropertyMap`
+/// \cgalModels{LvaluePropertyMap}
 template <typename T>
 struct Identity_property_map
 {
@@ -387,7 +385,7 @@ Identity_property_map<T>
 /// \ingroup PkgPropertyMapRef
 /// Property map that accesses the first item of a `std::pair`.
 /// \tparam Pair Instance of `std::pair`.
-/// \cgalModels `LvaluePropertyMap`
+/// \cgalModels{LvaluePropertyMap}
 ///
 /// \sa `CGAL::Second_of_pair_property_map<Pair>`
 template <typename Pair>
@@ -427,7 +425,7 @@ First_of_pair_property_map<Pair>
 ///
 /// \tparam Pair Instance of `std::pair`.
 ///
-/// \cgalModels `LvaluePropertyMap`
+/// \cgalModels{LvaluePropertyMap}
 ///
 /// \sa `CGAL::First_of_pair_property_map<Pair>`
 template <typename Pair>
@@ -468,7 +466,7 @@ Second_of_pair_property_map<Pair>
 /// \tparam N %Index of the item to access.
 /// \tparam Tuple Instance of `boost::tuple` or `std::tuple`.
 ///
-/// \cgalModels `LvaluePropertyMap`
+/// \cgalModels{LvaluePropertyMap}
 template <int N, typename Tuple>
 struct Nth_of_tuple_property_map
 {
@@ -613,7 +611,7 @@ make_property_map(const std::vector<T>& v)
 /// Note that this value is chosen when the map is constructed and cannot
 /// be changed afterwards. Specifically, the free function `put()` does nothing.
 ///
-/// \cgalModels `ReadWritePropertyMap`
+/// \cgalModels{ReadWritePropertyMap}
 template<class KeyType, class ValueType>
 struct Constant_property_map
 {
@@ -624,7 +622,8 @@ struct Constant_property_map
   typedef const value_type&                             reference;
   typedef boost::read_write_property_map_tag            category;
 
-  Constant_property_map(const value_type& default_value = value_type()) : default_value (default_value) { }
+  Constant_property_map() : default_value{} { }
+  Constant_property_map(const value_type& default_value) : default_value (default_value) { }
 
   /// Free function that returns `pm.default_value`.
   inline friend
@@ -642,7 +641,7 @@ struct Constant_property_map
 /// return `true` if the key is inside the set and `false` otherwise. The `put`
 /// function will insert an element in the set if `true` is passed and erase it
 /// otherwise.
-/// \cgalModels `ReadWritePropertyMap`
+/// \cgalModels{ReadWritePropertyMap}
 template<class Set>
 struct Boolean_property_map
 {
@@ -663,7 +662,7 @@ struct Boolean_property_map
     return pm.set_ptr->count(k) != 0;
   }
 
-  friend void put(Boolean_property_map<Set>& pm, const key_type& k, bool v)
+  friend void put(Boolean_property_map<Set> pm, const key_type& k, bool v)
   {
     CGAL_assertion(pm.set_ptr!=nullptr);
     if (v)
@@ -690,7 +689,7 @@ make_boolean_property_map(Set& set_)
 /// a geometric object of the same type as `GeomObject` but possibly from
 /// another kernel.
 /// Conversions between the two geometric objects are done using `Cartesian_converter`.
-/// \cgalModels `ReadWritePropertyMap`
+/// \cgalModels{ReadWritePropertyMap}
 template<class GeomObject, class Vpm>
 struct Cartesian_converter_property_map
 {
@@ -727,8 +726,8 @@ make_cartesian_converter_property_map(Vpm vpm)
 
 /// \ingroup PkgPropertyMapRef
 /// A property map with `std::size_t` as key-type that can be used
-/// to access the i'th element in a container with random access.
-/// \cgalModels `LvaluePropertyMap`, constness being than of `Container`.
+/// to access the i-th element in a container with random access.
+/// \cgalModels{LvaluePropertyMap constness being than of `Container`.}
 template<typename Container>
 class Random_access_property_map
 {
