@@ -8,8 +8,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/STL_Extension/include/CGAL/utility.h $
-// $Id: include/CGAL/utility.h 50cfbde3b84 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/STL_Extension/include/CGAL/utility.h $
+// $Id: include/CGAL/utility.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -344,6 +344,12 @@ Scope_exit<F> make_scope_exit(F&& f) {
   return Scope_exit<F>(std::forward<F>(f));
 }
 
+template<class... Ts>
+struct overloaded : Ts... {
+  using Ts::operator()...;
+};
+template<class... Ts> overloaded(Ts...) -> overloaded<Ts...>;
+
 } //namespace CGAL
 
 namespace std {
